@@ -26,6 +26,7 @@
 
 #include <string>
 #include <list>
+#include <map>
 
 #include "common/scummsys.h"
 
@@ -82,8 +83,11 @@ public:
 	uint8 getVerIMEX() const;
 	uint8 getSuffixIM() const;
 	uint8 getSuffixEX() const;
+	uint32 getFuncNamesCount() const;
 
-	void deGob(int32 offset = -1);
+	void loadIDE(const byte *ideData);
+
+	void deGob(int32 offset = -1, bool isLib = false);
 
 protected:
 	enum FuncType {
@@ -136,10 +140,10 @@ protected:
 	uint32 readUint32();
 	const char *readString();
 
-	uint8 peekUint8() const;
-	uint16 peekUint16() const;
-	uint32 peekUint32() const;
-	const char *peekString() const;
+	uint8 peekUint8(int32 offset = 0) const;
+	uint16 peekUint16(int32 offset = 0) const;
+	uint32 peekUint32(int32 offset = 0) const;
+	const char *peekString(int32 offset = 0) const;
 
 	void skipExpr(char stopToken = 99);
 	std::string readExpr(char stopToken = 99);
@@ -171,6 +175,7 @@ protected:
 	ExtTable *_extTable;
 
 	std::list<uint32> _funcOffsets;
+	std::map<uint32, std::string> _funcOffsetsNames;
 
 	// Script properties
 	uint16 _start, _textCenter;
@@ -248,6 +253,7 @@ protected:
 	void o1_loadMultObject(FuncParams &params);
 
 	void o1_dummy(FuncParams &params);
+	void o1_copySprite(FuncParams &params);
 };
 
 class Script_v2 : public Script_v1 {
@@ -622,4 +628,47 @@ protected:
 	void o6_createSprite(FuncParams &params);
 };
 
+class Script_v7 : public Script_v6 {
+public:
+	Script_v7(byte *totData, uint32 totSize, ExtTable *extTable = 0);
+	virtual ~Script_v7();
+
+protected:
+	typedef void (Script_v7::*OpcodeDrawProcV7)(FuncParams &);
+	typedef void (Script_v7::*OpcodeFuncProcV7)(FuncParams &);
+	typedef void (Script_v7::*OpcodeGoblinProcV7)(FuncParams &);
+	struct OpcodeDrawEntryV7 {
+		FuncType type;
+		OpcodeDrawProcV7 proc;
+		const char *desc;
+		const Param params[16];
+	};
+	struct OpcodeFuncEntryV7 {
+		FuncType type;
+		OpcodeFuncProcV7 proc;
+		const char *desc;
+		const Param params[16];
+	};
+	struct OpcodeGoblinEntryV7 {
+		FuncType type;
+		OpcodeGoblinProcV7 proc;
+		const char *desc;
+		const Param params[16];
+	};
+	const OpcodeDrawEntryV7 *_opcodesDrawV7;
+	const OpcodeFuncEntryV7 *_opcodesFuncV7;
+	const OpcodeGoblinEntryV7 *_opcodesGoblinV7;
+	static const int _goblinFuncLookUp[][2];
+
+	virtual void setupOpcodes();
+	virtual void drawOpcode(byte i, FuncParams &params);
+	virtual void funcOpcode(byte i, byte j, FuncParams &params);
+	virtual void goblinOpcode(int i, FuncParams &params);
+
+	void o7_loadCursor(FuncParams &params);
+	void oPlaytoons_printText(FuncParams &params);
+	void o7_oemToANSI(FuncParams &params);
+	void oPlaytoons_freeSprite(FuncParams &params);
+};
+
 #endif // DEGOB_SCRIPT_H
