@@ -886,7 +886,7 @@ void Script_v2::o2_loadMapObjects(FuncParams &params) {
 
 	id = (int16) readUint16();
 	print("%d", id);
-	if (id != -1) {
+	if ((uint16) id < 65520) {
 		int16 count = (int16) readUint16();
 		print(", %d", count);
 		for (int i = 0; i < count; i++)
