@@ -1,13 +1,13 @@
-/* ResidualVM - A 3D game interpreter
+/* ScummVM Tools
  *
- * ResidualVM is the legal property of its developers, whose names
+ * ScummVM Tools is the legal property of its developers, whose names
  * are too numerous to list here. Please refer to the COPYRIGHT
  * file distributed with this source distribution.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,15 +15,14 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
-#include <tools/lua/lua.h>
-#include <tools/lua/lundump.h>
-#include <tools/lua/lopcodes.h>
-#include <tools/lua/lzio.h>
+#include <engines/grim/lua/lua.h>
+#include <engines/grim/lua/lundump.h>
+#include <engines/grim/lua/lopcodes.h>
+#include <engines/grim/lua/lzio.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -417,6 +416,7 @@ void Decompiler::do_multi_assign(Byte *&start) {
       num_tables++;
       // this needs stuff from farther up the stack, wait until
       // it's available
+      // fall-through
 
     case SETTABLE0:
       results.push(new IndexExpr(start, NULL, NULL));
@@ -909,6 +909,7 @@ void Decompiler::decompileRange(Byte *start, Byte *end) {
 
     case SETLISTW:
       start += 2;
+      goto setlist;
 
     case SETLIST0:
     setlist:
