@@ -1,13 +1,13 @@
-/* ResidualVM - A 3D game interpreter
+/* ScummVM Tools
  *
- * ResidualVM is the legal property of its developers, whose names
+ * ScummVM Tools is the legal property of its developers, whose names
  * are too numerous to list here. Please refer to the COPYRIGHT
  * file distributed with this source distribution.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,26 +15,21 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
-/* This file is part of libmspack.
+/*
  * (C) 2003-2004 Stuart Caie.
  *
- * This source code is adopted and striped for ScummVM project.
+ * This source code (libmspack) is adopted and striped for ScummVM project.
  *
  * The deflate method was created by Phil Katz. MSZIP is equivalent to the
  * deflate method.
  *
- * libmspack is free software; you can redistribute it and/or modify it under
- * the terms of the GNU Lesser General Public License (LGPL) version 2.1
- *
- * For further details, see the file COPYING.LIB distributed with libmspack
  */
 
-#include "tools/patchex/mszip.h"
+#include "engines/grim/patchex/mszip.h"
 
 static const unsigned short lit_lengths[29] = {
   3, 4, 5, 6, 7, 8, 9, 10, 11, 13, 15, 17, 19, 23, 27,
@@ -130,9 +125,9 @@ static int zipd_read_input(struct mszipd_stream *zip) {
 static int make_decode_table(unsigned int nsyms, unsigned int nbits,
 			     unsigned char *length, unsigned short *table)
 {
-  register unsigned int leaf, reverse, fill;
-  register unsigned short sym, next_sym;
-  register unsigned char bit_num;
+  unsigned int leaf, reverse, fill;
+  unsigned short sym, next_sym;
+  unsigned char bit_num;
   unsigned int pos         = 0;
   unsigned int table_mask  = 1 << nbits;
   unsigned int bmask    = table_mask >> 1;
@@ -209,8 +204,8 @@ static int make_decode_table(unsigned int nsyms, unsigned int nbits,
 } while (0)
 
 static int zip_read_lens(struct mszipd_stream *zip) {
-  register unsigned int bit_buffer;
-  register int bits_left;
+  unsigned int bit_buffer;
+  int bits_left;
   unsigned char *i_ptr, *i_end;
 
   unsigned short bl_table[(1 << 7)];
@@ -268,9 +263,9 @@ static int zip_read_lens(struct mszipd_stream *zip) {
 static int inflate(struct mszipd_stream *zip) {
   unsigned int last_block, block_type, distance, length, this_run, i;
 
-  register unsigned int bit_buffer;
-  register int bits_left;
-  register unsigned short sym;
+  unsigned int bit_buffer;
+  int bits_left;
+  unsigned short sym;
   unsigned char *i_ptr, *i_end;
 
   RESTORE_BITS;
@@ -484,8 +479,8 @@ struct mszipd_stream *mszipd_init(struct mspack_system *system,
 }
 
 int mszipd_decompress(struct mszipd_stream *zip, off_t out_bytes) {
-  register unsigned int bit_buffer;
-  register int bits_left;
+  unsigned int bit_buffer;
+  int bits_left;
   unsigned char *i_ptr, *i_end;
 
   int i, state, error;
@@ -555,9 +550,7 @@ int mszipd_decompress(struct mszipd_stream *zip, off_t out_bytes) {
 }
 
 void mszipd_free(struct mszipd_stream *zip) {
-  struct mspack_system *sys;
   if (zip) {
-    sys = zip->sys;
     free(zip->inbuf);
     free(zip);
   }
